@@ -49,6 +49,7 @@ use Symfony\Component\HttpFoundation\ParameterBag;
  * * state
  * * country
  * * phone
+ * * phoneExtension
  * * fax
  * * number
  * * expiryMonth
@@ -821,6 +822,27 @@ class CreditCard
         return $this->setParameter('billingPhone', $value);
     }
 
+    /**
+     * Get the billing phone number extension.
+     *
+     * @return string
+     */
+    public function getBillingPhoneExtension()
+    {
+        return $this->getParameter('billingPhoneExtension');
+    }
+
+    /**
+     * Sets the billing phone number extension.
+     *
+     * @param string $value
+     * @return CreditCard provides a fluent interface.
+     */
+    public function setBillingPhoneExtension($value)
+    {
+        return $this->setParameter('billingPhoneExtension', $value);
+    }
+
     /**
      * Get the billing fax number.
      *
@@ -1098,6 +1120,27 @@ class CreditCard
         return $this->setParameter('shippingPhone', $value);
     }
 
+    /**
+     * Get the shipping phone number extension.
+     *
+     * @return string
+     */
+    public function getShippingPhoneExtension()
+    {
+        return $this->getParameter('shippingPhoneExtension');
+    }
+
+    /**
+     * Sets the shipping phone number extension.
+     *
+     * @param string $value
+     * @return CreditCard provides a fluent interface.
+     */
+    public function setShippingPhoneExtension($value)
+    {
+        return $this->setParameter('shippingPhoneExtension', $value);
+    }
+
     /**
      * Get the shipping fax number.
      *
@@ -1287,6 +1330,30 @@ class CreditCard
         return $this;
     }
 
+    /**
+     * Get the billing phone number extension.
+     *
+     * @return string
+     */
+    public function getPhoneExtension()
+    {
+        return $this->getParameter('billingPhoneExtension');
+    }
+
+    /**
+     * Sets the billing and shipping phone number extension.
+     *
+     * @param string $value
+     * @return CreditCard provides a fluent interface.
+     */
+    public function setPhoneExtension($value)
+    {
+        $this->setParameter('billingPhoneExtension', $value);
+        $this->setParameter('shippingPhoneExtension', $value);
+
+        return $this;
+    }
+
     /**
      * Get the billing fax number..
      *
